@@ -1,9 +1,5 @@
 from enum import Enum
 
-SLASH_COMMAND = 1
-USER_COMMAND = 2
-MESSAGE_COMMAND = 3
-
 CHANNEL_WITH_SOURCE = 4
 DEFERRED_CHANNEL_WITH_SOURCE = 5
 DEFERRED_UPDATE_MESSAGE = 6
@@ -15,7 +11,7 @@ T_SLASH_COMMAND = 2
 T_COMPONENT = 3
 T_MODAL_SUBMIT = 5
 
-__version__ = '0.0.12'
+__version__ = '0.1.0'
 
 class DefaultAvatars(Enum):
     blurple = 0
@@ -34,3 +30,4 @@ def return_avatar_as_cdn(avatar, uid):
         suffix = 'gif' if animated else 'png'
         return f"https://cdn.discordapp.com/avatars/{uid}/{avatar}.{suffix}?size=1024"
     return f"https://cdn.discordapp.com/embed/avatars/{uid%len(DefaultAvatars)}.png"
+
